/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.command;

import java.util.List;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.ConnectorEditPartBase;
import org.fortiss.tooling.base.ui.editpart.LayoutedConnectionEditPartBase;
import org.fortiss.tooling.base.ui.layout.util.LayoutDataUtils;

/**
 * A {@link Command} storing a {@link ChangeBoundsRequest}.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 97E72763FD3655AAF658FF43EAA8C3CF
 */
public abstract class ChangeBoundsRequestCommandBase extends Command {

	/** The creation request */
	private final ChangeBoundsRequest request;

	/** Constructor */
	public ChangeBoundsRequestCommandBase(ChangeBoundsRequest request) {
		this.request = request;
	}

	/** Returns the stored request. */
	protected ChangeBoundsRequest getRequest() {
		return request;
	}

	/** {@inheritDoc} */
	@Override
	@SuppressWarnings("unchecked")
	public void execute() {
		bendpointGroupMove(request.getEditParts());
	}

	/** Moves the given node using info from {@link #getRequest()}. */
	protected void moveNode(ILayoutedModelElement layouted) {
		int dx = getRequest().getMoveDelta().x;
		int dy = getRequest().getMoveDelta().y;
		LayoutDataUtils.moveNode(layouted, dx, dy);
	}

	/** Moves and resizes the given node using info from {@link #getRequest()}. */
	protected void moveAndResizeNode(ILayoutedModelElement layouted,
			int minWidth, int minHeight) {
		int dx = getRequest().getMoveDelta().x;
		int dy = getRequest().getMoveDelta().y;
		int dw = getRequest().getSizeDelta().width;
		int dh = getRequest().getSizeDelta().height;
		LayoutDataUtils.moveAndResizeNode(layouted, dx, dy, dw, dh, minWidth,
				minHeight);
	}

	/** Move bend points along with a group of selected elements */
	@SuppressWarnings({ "unchecked", "rawtypes" })
	private void bendpointGroupMove(List<EditPart> parts) {
		for (EditPart part : parts) {
			// cover also sticky connectors
			if (part.getChildren().size() > 0) {
				bendpointGroupMove(part.getChildren());
			}
			// filter non connective edit parts
			if (!(part instanceof ConnectorEditPartBase)) {
				break;
			}
			ConnectorEditPartBase connector = (ConnectorEditPartBase) part;
			for (LayoutedConnectionEditPartBase connection : (List<LayoutedConnectionEditPartBase>) connector
					.getSourceConnections()) {
				if (connection.getTarget().getSelected() != EditPart.SELECTED_NONE) {
					LayoutDataUtils.changeAllConnectionPoints(
							(ILayoutedModelElement) connection.getModel(),
							request.getMoveDelta().x, request.getMoveDelta().y);
				}
			}
		}
	}
}
