/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.ecore.util.EContentAdapter;
import org.fortiss.tooling.base.model.element.IConnection;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.LayoutPackage;

/**
 * The base class for all layouted connection edit parts. This makes sure the
 * edit part is updated if the layout data changes in some way.
 * 
 * @param <T>
 *            the type of the model element wrapped.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 4528B935FD404A834CBD215E46A1BFC1
 */
public abstract class LayoutedConnectionEditPartBase<T extends ILayoutedModelElement & IConnection>
		extends ConnectionEditPartBase<T> {

	// TODO (FH): check for collision with full refresh adapter of super class !

	/** The adapter used for dealing with changes of the */
	protected final Adapter layoutChanged = new EContentAdapter() {

		@Override
		public void notifyChanged(Notification notification) {

			// skip everything that is not layout related
			if (notification.getNotifier() == modelElement) {
				if (notification.getFeature() != LayoutPackage.Literals.ILAYOUTED_MODEL_ELEMENT__LAYOUT_DATA) {
					return;
				}
			}

			super.notifyChanged(notification);
			refresh();
		}
	};

	/** Constructor. */
	protected LayoutedConnectionEditPartBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public void activate() {
		super.activate();
		modelElement.eAdapters().add(layoutChanged);
	}

	/** {@inheritDoc} */
	@Override
	public void deactivate() {
		modelElement.eAdapters().remove(layoutChanged);
		super.deactivate();
	}
}
