/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.layout.util;

import org.fortiss.tooling.base.model.layout.Angle;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.LayoutFactory;

/**
 * Utility methods for {@link Angle} layout data.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 183CE3430521A9C9D9AF01E6B7D243D9
 */
/* package */final class AngleUtil {

	/** Creates a new {@link Angle}. */
	public static Angle createAngle(double angle) {
		Angle a = LayoutFactory.eINSTANCE.createAngle();
		a.setAngle(angle);
		return a;
	}

	/** Returns an angle. */
	public static Angle getAngle(ILayoutedModelElement lobject, String key) {
		for (ILayoutData ld : lobject.getLayoutDataList()) {
			if (ld.getKey().equals(key) && ld instanceof Angle) {
				return (Angle) ld;
			}
		}
		return null;
	}

	/** Sets a {@link Angle} layout data. */
	public static void setAngle(ILayoutedModelElement lobject, String key,
			double angle) {
		Angle old = getAngle(lobject, key);
		if (old != null) {
			lobject.getLayoutDataList().remove(old);
		}

		Angle a = createAngle(angle);
		a.setKey(key);
		lobject.getLayoutDataList().add(a);
	}
}
