/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2005-2010 Technische Universitaet Muenchen                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.util;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.core.runtime.Status;

/**
 * Utility code for performing logging.
 * 
 * Note: This class originates form the org.conqat.ide.commons.ui
 * implementation. It re-packaged with the kernel to avoid any dependency to
 * eclipse.ui packages. See http://www.conqat.org for the original version.
 * 
 * @author hummel
 * @author schwitze
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 5489A04000105CF881046928C19E6E14
 */
public class LoggingUtils {

	/**
	 * Logs a message that occurred in the context of the given plug-in with the
	 * given severity.
	 * 
	 * @see IStatus
	 * 
	 * @param plugin
	 *            The plug-in that logs the message in its context.
	 * @param message
	 *            The message text to log.
	 * @param severity
	 *            The severity of the log message. See {@link IStatus} for valid
	 *            constants.
	 * 
	 */
	public static void log(Plugin plugin, String message, int severity) {
		log(plugin, message, severity, null);
	}

	/**
	 * Logs a message that occurred in the context of the given plug-in with the
	 * given severity and a given {@link Throwable} that originally caused this
	 * log message.
	 * 
	 * @see IStatus
	 * 
	 * @param plugin
	 *            The plug-in that logs the message in its context.
	 * @param message
	 *            The message text to log.
	 * @param severity
	 *            The severity of the log message. See {@link IStatus} for valid
	 *            constants.
	 * @param cause
	 *            The {@link Throwable} that originally caused this log message.
	 */
	public static void log(Plugin plugin, String message, int severity,
			Throwable cause) {
		String pluginId = plugin.getBundle().getSymbolicName();
		IStatus status = new Status(severity, pluginId, message, cause);
		plugin.getLog().log(status);
	}

	/**
	 * Logs an exception that occurred in the context of the given plug-in with
	 * the severity {@link IStatus#ERROR}.
	 * 
	 * @param plugin
	 *            The plug-in that logs the message in its context.
	 * @param message
	 *            The message text to log.
	 * @param cause
	 *            The {@link Throwable} that originally caused this log message.
	 */
	public static void error(Plugin plugin, String message, Throwable cause) {
		log(plugin, message, IStatus.ERROR, cause);
	}
}
